# Part of LineDream: A Python package for creative coding
# Copyright (C) 2020- Marc Leonard
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#

__title__ = 'LineDream'
__description__ = 'A creative coding library...'
__url__ = 'https://linedream.marcrleonard.com/'
# __url__ = 'https://github.com/marcrleonard/LineDream'
__version__ = '0.1.12'
__author__ = 'Marc Leonard'
__author_email__ = 'marc.r.leonard@gmail.com'
__license__ = 'GNU GPLv3'
__copyright__ = 'Copyright (C) 2021 - Marc Leonard'
